# This code is part of a Qiskit project.
#
# (C) Copyright IBM 2022, 2024.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

import inspect
import os
import re
import sys

import setuptools

with open("requirements.txt", "r", encoding="utf-8") as f:
    REQUIREMENTS = f.read().splitlines()

VERSION_PATH = os.path.join(os.path.dirname(__file__), "qiskit_nature_pyscf", "VERSION.txt")
with open(VERSION_PATH, "r", encoding="utf-8") as version_file:
    VERSION = version_file.read().strip()

# Read long description from README.
README_PATH = os.path.join(os.path.abspath(os.path.dirname(__file__)), "README.md")
with open(README_PATH, "r", encoding="utf-8") as readme_file:
    README = re.sub(
        "<!--- long-description-skip-begin -->.*<!--- long-description-skip-end -->",
        "",
        readme_file.read(),
        flags=re.S | re.M,
    )

setuptools.setup(
    name="qiskit-nature-pyscf",
    version=VERSION,
    description="Qiskit Nature PySCF: Third-party integration plugin of Qiskit Nature + PySCF.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/qiskit-community/qiskit-nature-pyscf",
    author="Qiskit Nature PySCF Development Team",
    author_email="qiskit@us.ibm.com",
    license="Apache-2.0",
    classifiers=[
        "Environment :: Console",
        "License :: OSI Approved :: Apache Software License",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Operating System :: MacOS",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Scientific/Engineering",
    ],
    keywords="qiskit sdk quantum nature chemistry physics pyscf",
    packages=setuptools.find_packages(include=["qiskit_nature_pyscf", "qiskit_nature_pyscf.*"]),
    install_requires=REQUIREMENTS,
    include_package_data=True,
    python_requires=">=3.8",
    project_urls={
        "Bug Tracker": "https://github.com/qiskit-community/qiskit-nature-pyscf/issues",
        "Documentation": "https://qiskit-community.github.io/qiskit-nature-pyscf/",
        "Source Code": "https://github.com/qiskit-community/qiskit-nature-pyscf",
    },
    zip_safe=False,
)
